# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: approval_workflows.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61pproval_workflows.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\x1a\x1egoogle/protobuf/duration.proto\"\x85\x01\n\x1d\x41pprovalWorkflowCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12;\n\x11\x61pproval_workflow\x18\x02 \x01(\x0b\x32\x14.v1.ApprovalWorkflowB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xec\x01\n\x1e\x41pprovalWorkflowCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12;\n\x11\x61pproval_workflow\x18\x02 \x01(\x0b\x32\x14.v1.ApprovalWorkflowB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"Z\n\x1a\x41pprovalWorkflowGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xf2\x01\n\x1b\x41pprovalWorkflowGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12;\n\x11\x61pproval_workflow\x18\x02 \x01(\x0b\x32\x14.v1.ApprovalWorkflowB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x85\x01\n\x1d\x41pprovalWorkflowUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12;\n\x11\x61pproval_workflow\x18\x02 \x01(\x0b\x32\x14.v1.ApprovalWorkflowB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xec\x01\n\x1e\x41pprovalWorkflowUpdateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadata\x12;\n\x11\x61pproval_workflow\x18\x02 \x01(\x0b\x32\x14.v1.ApprovalWorkflowB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"`\n\x1d\x41pprovalWorkflowDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xc7\x01\n\x1e\x41pprovalWorkflowDeleteResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"`\n\x1b\x41pprovalWorkflowListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xe9\x01\n\x1c\x41pprovalWorkflowListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12<\n\x12\x61pproval_workflows\x18\x02 \x03(\x0b\x32\x14.v1.ApprovalWorkflowB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\x89\x03\n\x10\x41pprovalWorkflow\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12&\n\rapproval_mode\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1f\n\x0b\x64\x65scription\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12}\n\x17\x61pproval_workflow_steps\x18\x05 \x03(\x0b\x32\x14.v1.ApprovalFlowStepBF\xf2\xf8\xb3\x07\x41\xb0\xf3\xb3\x07\x01\xca\xf3\xb3\x07(\xc2\xf4\xb3\x07#\n\x12terraform-provider\x12\rapproval_step\xb2\xf4\xb3\x07\x01*\xb2\xf4\xb3\x07\x04!cli:v\xfa\xf8\xb3\x07q\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07\x61\xa2\xf3\xb3\x07*tf_examples/approval_workflow_resource.txt\xaa\xf3\xb3\x07-tf_examples/approval_workflow_data_source.txt\xd2\xf3\xb3\x07\x01*\"\xb3\x02\n\x10\x41pprovalFlowStep\x12\x1e\n\nquantifier\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x39\n\nskip_after\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x64\n\tapprovers\x18\x03 \x03(\x0b\x32\x18.v1.ApprovalFlowApproverB7\xf2\xf8\xb3\x07\x32\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\xca\xf3\xb3\x07#\xc2\xf4\xb3\x07\x1e\n\x12terraform-provider\x12\x08\x61pprover:^\xfa\xf8\xb3\x07Y\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07@\xf2\xf3\xb3\x07\x1e\n\x12terraform-provider\x12\x08TypeList\xfa\xf3\xb3\x07\x18\x61pprovalFlowStepElemType\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x04!cli\"\xf4\x01\n\x14\x41pprovalFlowApprover\x12\x1e\n\naccount_id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1b\n\x07role_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\treference\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1c\n\x08group_id\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:b\xfa\xf8\xb3\x07]\xa8\xf3\xb3\x07\x01\xca\xf3\xb3\x07\x44\xf2\xf3\xb3\x07\x1e\n\x12terraform-provider\x12\x08TypeList\xfa\xf3\xb3\x07\x1c\x61pprovalFlowApproverElemType\xd2\xf3\xb3\x07\x01*\xd2\xf3\xb3\x07\x04!cli2\xcb\x05\n\x11\x41pprovalWorkflows\x12\x7f\n\x06\x43reate\x12!.v1.ApprovalWorkflowCreateRequest\x1a\".v1.ApprovalWorkflowCreateResponse\".\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/approval-workflows\x12y\n\x03Get\x12\x1e.v1.ApprovalWorkflowGetRequest\x1a\x1f.v1.ApprovalWorkflowGetResponse\"1\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1f\xaa\xf3\xb3\x07\x1a/v1/approval-workflow/{id}\x12\x81\x01\n\x06\x44\x65lete\x12!.v1.ApprovalWorkflowDeleteRequest\x1a\".v1.ApprovalWorkflowDeleteResponse\"0\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/approval-workflows\x12~\n\x06Update\x12!.v1.ApprovalWorkflowUpdateRequest\x1a\".v1.ApprovalWorkflowUpdateResponse\"-\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/approval-workflows\x12x\n\x04List\x12\x1f.v1.ApprovalWorkflowListRequest\x1a .v1.ApprovalWorkflowListResponse\"-\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/approval-workflows\x1a<\xca\xf9\xb3\x07\x15\xc2\xf9\xb3\x07\x10\x41pprovalWorkflow\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03\x61\x66-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*Bm\n\x19\x63om.strongdm.api.plumbingB\x19\x41pprovalWorkflowsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_APPROVALWORKFLOWCREATEREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowCreateRequest']
_APPROVALWORKFLOWCREATERESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowCreateResponse']
_APPROVALWORKFLOWGETREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowGetRequest']
_APPROVALWORKFLOWGETRESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowGetResponse']
_APPROVALWORKFLOWUPDATEREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowUpdateRequest']
_APPROVALWORKFLOWUPDATERESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowUpdateResponse']
_APPROVALWORKFLOWDELETEREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowDeleteRequest']
_APPROVALWORKFLOWDELETERESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowDeleteResponse']
_APPROVALWORKFLOWLISTREQUEST = DESCRIPTOR.message_types_by_name['ApprovalWorkflowListRequest']
_APPROVALWORKFLOWLISTRESPONSE = DESCRIPTOR.message_types_by_name['ApprovalWorkflowListResponse']
_APPROVALWORKFLOW = DESCRIPTOR.message_types_by_name['ApprovalWorkflow']
_APPROVALFLOWSTEP = DESCRIPTOR.message_types_by_name['ApprovalFlowStep']
_APPROVALFLOWAPPROVER = DESCRIPTOR.message_types_by_name['ApprovalFlowApprover']
ApprovalWorkflowCreateRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWCREATEREQUEST,
  '__module__' : 'approval_workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowCreateRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowCreateRequest)

ApprovalWorkflowCreateResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWCREATERESPONSE,
  '__module__' : 'approval_workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowCreateResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowCreateResponse)

ApprovalWorkflowGetRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWGETREQUEST,
  '__module__' : 'approval_workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowGetRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowGetRequest)

ApprovalWorkflowGetResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWGETRESPONSE,
  '__module__' : 'approval_workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowGetResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowGetResponse)

ApprovalWorkflowUpdateRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWUPDATEREQUEST,
  '__module__' : 'approval_workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowUpdateRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowUpdateRequest)

ApprovalWorkflowUpdateResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWUPDATERESPONSE,
  '__module__' : 'approval_workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowUpdateResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowUpdateResponse)

ApprovalWorkflowDeleteRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWDELETEREQUEST,
  '__module__' : 'approval_workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowDeleteRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowDeleteRequest)

ApprovalWorkflowDeleteResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWDELETERESPONSE,
  '__module__' : 'approval_workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowDeleteResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowDeleteResponse)

ApprovalWorkflowListRequest = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowListRequest', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWLISTREQUEST,
  '__module__' : 'approval_workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowListRequest)
  })
_sym_db.RegisterMessage(ApprovalWorkflowListRequest)

ApprovalWorkflowListResponse = _reflection.GeneratedProtocolMessageType('ApprovalWorkflowListResponse', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOWLISTRESPONSE,
  '__module__' : 'approval_workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflowListResponse)
  })
_sym_db.RegisterMessage(ApprovalWorkflowListResponse)

ApprovalWorkflow = _reflection.GeneratedProtocolMessageType('ApprovalWorkflow', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALWORKFLOW,
  '__module__' : 'approval_workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalWorkflow)
  })
_sym_db.RegisterMessage(ApprovalWorkflow)

ApprovalFlowStep = _reflection.GeneratedProtocolMessageType('ApprovalFlowStep', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALFLOWSTEP,
  '__module__' : 'approval_workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalFlowStep)
  })
_sym_db.RegisterMessage(ApprovalFlowStep)

ApprovalFlowApprover = _reflection.GeneratedProtocolMessageType('ApprovalFlowApprover', (_message.Message,), {
  'DESCRIPTOR' : _APPROVALFLOWAPPROVER,
  '__module__' : 'approval_workflows_pb2'
  # @@protoc_insertion_point(class_scope:v1.ApprovalFlowApprover)
  })
_sym_db.RegisterMessage(ApprovalFlowApprover)

_APPROVALWORKFLOWS = DESCRIPTOR.services_by_name['ApprovalWorkflows']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\031ApprovalWorkflowsPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _APPROVALWORKFLOWCREATEREQUEST.fields_by_name['approval_workflow']._options = None
  _APPROVALWORKFLOWCREATEREQUEST.fields_by_name['approval_workflow']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWCREATERESPONSE.fields_by_name['approval_workflow']._options = None
  _APPROVALWORKFLOWCREATERESPONSE.fields_by_name['approval_workflow']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWCREATERESPONSE._options = None
  _APPROVALWORKFLOWCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWGETREQUEST.fields_by_name['id']._options = None
  _APPROVALWORKFLOWGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWGETRESPONSE.fields_by_name['meta']._options = None
  _APPROVALWORKFLOWGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWGETRESPONSE.fields_by_name['approval_workflow']._options = None
  _APPROVALWORKFLOWGETRESPONSE.fields_by_name['approval_workflow']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWGETRESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWGETRESPONSE._options = None
  _APPROVALWORKFLOWGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWUPDATEREQUEST.fields_by_name['approval_workflow']._options = None
  _APPROVALWORKFLOWUPDATEREQUEST.fields_by_name['approval_workflow']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWUPDATERESPONSE.fields_by_name['approval_workflow']._options = None
  _APPROVALWORKFLOWUPDATERESPONSE.fields_by_name['approval_workflow']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWUPDATERESPONSE._options = None
  _APPROVALWORKFLOWUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWDELETEREQUEST.fields_by_name['id']._options = None
  _APPROVALWORKFLOWDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWDELETERESPONSE.fields_by_name['id']._options = None
  _APPROVALWORKFLOWDELETERESPONSE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWDELETERESPONSE._options = None
  _APPROVALWORKFLOWDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOWLISTREQUEST.fields_by_name['filter']._options = None
  _APPROVALWORKFLOWLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOWLISTRESPONSE.fields_by_name['approval_workflows']._options = None
  _APPROVALWORKFLOWLISTRESPONSE.fields_by_name['approval_workflows']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _APPROVALWORKFLOWLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _APPROVALWORKFLOWLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _APPROVALWORKFLOWLISTRESPONSE._options = None
  _APPROVALWORKFLOWLISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _APPROVALWORKFLOW.fields_by_name['id']._options = None
  _APPROVALWORKFLOW.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOW.fields_by_name['name']._options = None
  _APPROVALWORKFLOW.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _APPROVALWORKFLOW.fields_by_name['approval_mode']._options = None
  _APPROVALWORKFLOW.fields_by_name['approval_mode']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _APPROVALWORKFLOW.fields_by_name['description']._options = None
  _APPROVALWORKFLOW.fields_by_name['description']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALWORKFLOW.fields_by_name['approval_workflow_steps']._options = None
  _APPROVALWORKFLOW.fields_by_name['approval_workflow_steps']._serialized_options = b'\362\370\263\007A\260\363\263\007\001\312\363\263\007(\302\364\263\007#\n\022terraform-provider\022\rapproval_step\262\364\263\007\001*\262\364\263\007\004!cli'
  _APPROVALWORKFLOW._options = None
  _APPROVALWORKFLOW._serialized_options = b'\372\370\263\007q\250\363\263\007\001\302\363\263\007a\242\363\263\007*tf_examples/approval_workflow_resource.txt\252\363\263\007-tf_examples/approval_workflow_data_source.txt\322\363\263\007\001*'
  _APPROVALFLOWSTEP.fields_by_name['quantifier']._options = None
  _APPROVALFLOWSTEP.fields_by_name['quantifier']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALFLOWSTEP.fields_by_name['skip_after']._options = None
  _APPROVALFLOWSTEP.fields_by_name['skip_after']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALFLOWSTEP.fields_by_name['approvers']._options = None
  _APPROVALFLOWSTEP.fields_by_name['approvers']._serialized_options = b'\362\370\263\0072\260\363\263\007\001\300\363\263\007\001\312\363\263\007#\302\364\263\007\036\n\022terraform-provider\022\010approver'
  _APPROVALFLOWSTEP._options = None
  _APPROVALFLOWSTEP._serialized_options = b'\372\370\263\007Y\250\363\263\007\001\312\363\263\007@\362\363\263\007\036\n\022terraform-provider\022\010TypeList\372\363\263\007\030approvalFlowStepElemType\322\363\263\007\001*\322\363\263\007\004!cli'
  _APPROVALFLOWAPPROVER.fields_by_name['account_id']._options = None
  _APPROVALFLOWAPPROVER.fields_by_name['account_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALFLOWAPPROVER.fields_by_name['role_id']._options = None
  _APPROVALFLOWAPPROVER.fields_by_name['role_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALFLOWAPPROVER.fields_by_name['reference']._options = None
  _APPROVALFLOWAPPROVER.fields_by_name['reference']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALFLOWAPPROVER.fields_by_name['group_id']._options = None
  _APPROVALFLOWAPPROVER.fields_by_name['group_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _APPROVALFLOWAPPROVER._options = None
  _APPROVALFLOWAPPROVER._serialized_options = b'\372\370\263\007]\250\363\263\007\001\312\363\263\007D\362\363\263\007\036\n\022terraform-provider\022\010TypeList\372\363\263\007\034approvalFlowApproverElemType\322\363\263\007\001*\322\363\263\007\004!cli'
  _APPROVALWORKFLOWS._options = None
  _APPROVALWORKFLOWS._serialized_options = b'\312\371\263\007\025\302\371\263\007\020ApprovalWorkflow\312\371\263\007\010\322\371\263\007\003af-\312\371\263\007\005\350\371\263\007\001\312\371\263\007\006\312\371\263\007\001*'
  _APPROVALWORKFLOWS.methods_by_name['Create']._options = None
  _APPROVALWORKFLOWS.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\033\252\363\263\007\026/v1/approval-workflows'
  _APPROVALWORKFLOWS.methods_by_name['Get']._options = None
  _APPROVALWORKFLOWS.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\037\252\363\263\007\032/v1/approval-workflow/{id}'
  _APPROVALWORKFLOWS.methods_by_name['Delete']._options = None
  _APPROVALWORKFLOWS.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\033\252\363\263\007\026/v1/approval-workflows'
  _APPROVALWORKFLOWS.methods_by_name['Update']._options = None
  _APPROVALWORKFLOWS.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\033\252\363\263\007\026/v1/approval-workflows'
  _APPROVALWORKFLOWS.methods_by_name['List']._options = None
  _APPROVALWORKFLOWS.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\033\252\363\263\007\026/v1/approval-workflows'
  _APPROVALWORKFLOWCREATEREQUEST._serialized_start=92
  _APPROVALWORKFLOWCREATEREQUEST._serialized_end=225
  _APPROVALWORKFLOWCREATERESPONSE._serialized_start=228
  _APPROVALWORKFLOWCREATERESPONSE._serialized_end=464
  _APPROVALWORKFLOWGETREQUEST._serialized_start=466
  _APPROVALWORKFLOWGETREQUEST._serialized_end=556
  _APPROVALWORKFLOWGETRESPONSE._serialized_start=559
  _APPROVALWORKFLOWGETRESPONSE._serialized_end=801
  _APPROVALWORKFLOWUPDATEREQUEST._serialized_start=804
  _APPROVALWORKFLOWUPDATEREQUEST._serialized_end=937
  _APPROVALWORKFLOWUPDATERESPONSE._serialized_start=940
  _APPROVALWORKFLOWUPDATERESPONSE._serialized_end=1176
  _APPROVALWORKFLOWDELETEREQUEST._serialized_start=1178
  _APPROVALWORKFLOWDELETEREQUEST._serialized_end=1274
  _APPROVALWORKFLOWDELETERESPONSE._serialized_start=1277
  _APPROVALWORKFLOWDELETERESPONSE._serialized_end=1476
  _APPROVALWORKFLOWLISTREQUEST._serialized_start=1478
  _APPROVALWORKFLOWLISTREQUEST._serialized_end=1574
  _APPROVALWORKFLOWLISTRESPONSE._serialized_start=1577
  _APPROVALWORKFLOWLISTRESPONSE._serialized_end=1810
  _APPROVALWORKFLOW._serialized_start=1813
  _APPROVALWORKFLOW._serialized_end=2206
  _APPROVALFLOWSTEP._serialized_start=2209
  _APPROVALFLOWSTEP._serialized_end=2516
  _APPROVALFLOWAPPROVER._serialized_start=2519
  _APPROVALFLOWAPPROVER._serialized_end=2763
  _APPROVALWORKFLOWS._serialized_start=2766
  _APPROVALWORKFLOWS._serialized_end=3481
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: peering_group_resources.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dpeering_group_resources.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"\x92\x01\n!PeeringGroupResourceCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x44\n\x16peering_group_resource\x18\x02 \x01(\x0b\x32\x18.v1.PeeringGroupResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\x85\x02\n\"PeeringGroupResourceCreateResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\x16peering_group_resource\x18\x02 \x01(\x0b\x32\x18.v1.PeeringGroupResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"^\n\x1ePeeringGroupResourceGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xff\x01\n\x1fPeeringGroupResourceGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x44\n\x16peering_group_resource\x18\x02 \x01(\x0b\x32\x18.v1.PeeringGroupResourceB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"d\n!PeeringGroupResourceDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xbf\x01\n\"PeeringGroupResourceDeleteResponse\x12\x34\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"d\n\x1fPeeringGroupResourceListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xea\x01\n PeeringGroupResourceListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x45\n\x17peering_group_resources\x18\x02 \x03(\x0b\x32\x18.v1.PeeringGroupResourceB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway\"\x83\x01\n\x14PeeringGroupResource\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x0bresource_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01\x12!\n\x08group_id\x18\x04 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xd0\xf4\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\x32\x96\x05\n\x15PeeringGroupResources\x12\x8a\x01\n\x06\x43reate\x12%.v1.PeeringGroupResourceCreateRequest\x1a&.v1.PeeringGroupResourceCreateResponse\"1\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x1e\xaa\xf3\xb3\x07\x19/v1/peeringGroupResources\x12\x91\x01\n\x06\x44\x65lete\x12%.v1.PeeringGroupResourceDeleteRequest\x1a&.v1.PeeringGroupResourceDeleteResponse\"8\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07#\xaa\xf3\xb3\x07\x1e/v1/peeringGroupResources/{id}\x12\x85\x01\n\x03Get\x12\".v1.PeeringGroupResourceGetRequest\x1a#.v1.PeeringGroupResourceGetResponse\"5\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07#\xaa\xf3\xb3\x07\x1e/v1/peeringGroupResources/{id}\x12\x83\x01\n\x04List\x12#.v1.PeeringGroupResourceListRequest\x1a$.v1.PeeringGroupResourceListResponse\"0\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1e\xaa\xf3\xb3\x07\x19/v1/peeringGroupResources\x1aN\xca\xf9\xb3\x07\x19\xc2\xf9\xb3\x07\x14PeeringGroupResource\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03gr-\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\t\xca\xf9\xb3\x07\x04!cli\xca\xf9\xb3\x07\x05\xd8\xf9\xb3\x07\x01\x42q\n\x19\x63om.strongdm.api.plumbingB\x1dPeeringGroupResourcesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_PEERINGGROUPRESOURCECREATEREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupResourceCreateRequest']
_PEERINGGROUPRESOURCECREATERESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupResourceCreateResponse']
_PEERINGGROUPRESOURCEGETREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupResourceGetRequest']
_PEERINGGROUPRESOURCEGETRESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupResourceGetResponse']
_PEERINGGROUPRESOURCEDELETEREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupResourceDeleteRequest']
_PEERINGGROUPRESOURCEDELETERESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupResourceDeleteResponse']
_PEERINGGROUPRESOURCELISTREQUEST = DESCRIPTOR.message_types_by_name['PeeringGroupResourceListRequest']
_PEERINGGROUPRESOURCELISTRESPONSE = DESCRIPTOR.message_types_by_name['PeeringGroupResourceListResponse']
_PEERINGGROUPRESOURCE = DESCRIPTOR.message_types_by_name['PeeringGroupResource']
PeeringGroupResourceCreateRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCECREATEREQUEST,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceCreateRequest)
  })
_sym_db.RegisterMessage(PeeringGroupResourceCreateRequest)

PeeringGroupResourceCreateResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCECREATERESPONSE,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceCreateResponse)
  })
_sym_db.RegisterMessage(PeeringGroupResourceCreateResponse)

PeeringGroupResourceGetRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCEGETREQUEST,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceGetRequest)
  })
_sym_db.RegisterMessage(PeeringGroupResourceGetRequest)

PeeringGroupResourceGetResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCEGETRESPONSE,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceGetResponse)
  })
_sym_db.RegisterMessage(PeeringGroupResourceGetResponse)

PeeringGroupResourceDeleteRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCEDELETEREQUEST,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceDeleteRequest)
  })
_sym_db.RegisterMessage(PeeringGroupResourceDeleteRequest)

PeeringGroupResourceDeleteResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCEDELETERESPONSE,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceDeleteResponse)
  })
_sym_db.RegisterMessage(PeeringGroupResourceDeleteResponse)

PeeringGroupResourceListRequest = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceListRequest', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCELISTREQUEST,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceListRequest)
  })
_sym_db.RegisterMessage(PeeringGroupResourceListRequest)

PeeringGroupResourceListResponse = _reflection.GeneratedProtocolMessageType('PeeringGroupResourceListResponse', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCELISTRESPONSE,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResourceListResponse)
  })
_sym_db.RegisterMessage(PeeringGroupResourceListResponse)

PeeringGroupResource = _reflection.GeneratedProtocolMessageType('PeeringGroupResource', (_message.Message,), {
  'DESCRIPTOR' : _PEERINGGROUPRESOURCE,
  '__module__' : 'peering_group_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.PeeringGroupResource)
  })
_sym_db.RegisterMessage(PeeringGroupResource)

_PEERINGGROUPRESOURCES = DESCRIPTOR.services_by_name['PeeringGroupResources']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\035PeeringGroupResourcesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _PEERINGGROUPRESOURCECREATEREQUEST.fields_by_name['peering_group_resource']._options = None
  _PEERINGGROUPRESOURCECREATEREQUEST.fields_by_name['peering_group_resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCECREATERESPONSE.fields_by_name['meta']._options = None
  _PEERINGGROUPRESOURCECREATERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCECREATERESPONSE.fields_by_name['peering_group_resource']._options = None
  _PEERINGGROUPRESOURCECREATERESPONSE.fields_by_name['peering_group_resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCECREATERESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPRESOURCECREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPRESOURCECREATERESPONSE._options = None
  _PEERINGGROUPRESOURCECREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPRESOURCEGETREQUEST.fields_by_name['id']._options = None
  _PEERINGGROUPRESOURCEGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCEGETRESPONSE.fields_by_name['meta']._options = None
  _PEERINGGROUPRESOURCEGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCEGETRESPONSE.fields_by_name['peering_group_resource']._options = None
  _PEERINGGROUPRESOURCEGETRESPONSE.fields_by_name['peering_group_resource']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCEGETRESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPRESOURCEGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPRESOURCEGETRESPONSE._options = None
  _PEERINGGROUPRESOURCEGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPRESOURCEDELETEREQUEST.fields_by_name['id']._options = None
  _PEERINGGROUPRESOURCEDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCEDELETERESPONSE.fields_by_name['meta']._options = None
  _PEERINGGROUPRESOURCEDELETERESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCEDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPRESOURCEDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPRESOURCEDELETERESPONSE._options = None
  _PEERINGGROUPRESOURCEDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPRESOURCELISTREQUEST.fields_by_name['filter']._options = None
  _PEERINGGROUPRESOURCELISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCELISTRESPONSE.fields_by_name['peering_group_resources']._options = None
  _PEERINGGROUPRESOURCELISTRESPONSE.fields_by_name['peering_group_resources']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _PEERINGGROUPRESOURCELISTRESPONSE.fields_by_name['rate_limit']._options = None
  _PEERINGGROUPRESOURCELISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _PEERINGGROUPRESOURCE.fields_by_name['id']._options = None
  _PEERINGGROUPRESOURCE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _PEERINGGROUPRESOURCE.fields_by_name['resource_id']._options = None
  _PEERINGGROUPRESOURCE.fields_by_name['resource_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\320\364\263\007\001'
  _PEERINGGROUPRESOURCE.fields_by_name['group_id']._options = None
  _PEERINGGROUPRESOURCE.fields_by_name['group_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\320\364\263\007\001'
  _PEERINGGROUPRESOURCE._options = None
  _PEERINGGROUPRESOURCE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _PEERINGGROUPRESOURCES._options = None
  _PEERINGGROUPRESOURCES._serialized_options = b'\312\371\263\007\031\302\371\263\007\024PeeringGroupResource\312\371\263\007\010\322\371\263\007\003gr-\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\t\312\371\263\007\004!cli\312\371\263\007\005\330\371\263\007\001'
  _PEERINGGROUPRESOURCES.methods_by_name['Create']._options = None
  _PEERINGGROUPRESOURCES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\036\252\363\263\007\031/v1/peeringGroupResources'
  _PEERINGGROUPRESOURCES.methods_by_name['Delete']._options = None
  _PEERINGGROUPRESOURCES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007#\252\363\263\007\036/v1/peeringGroupResources/{id}'
  _PEERINGGROUPRESOURCES.methods_by_name['Get']._options = None
  _PEERINGGROUPRESOURCES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007#\252\363\263\007\036/v1/peeringGroupResources/{id}'
  _PEERINGGROUPRESOURCES.methods_by_name['List']._options = None
  _PEERINGGROUPRESOURCES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\036\252\363\263\007\031/v1/peeringGroupResources'
  _PEERINGGROUPRESOURCECREATEREQUEST._serialized_start=65
  _PEERINGGROUPRESOURCECREATEREQUEST._serialized_end=211
  _PEERINGGROUPRESOURCECREATERESPONSE._serialized_start=214
  _PEERINGGROUPRESOURCECREATERESPONSE._serialized_end=475
  _PEERINGGROUPRESOURCEGETREQUEST._serialized_start=477
  _PEERINGGROUPRESOURCEGETREQUEST._serialized_end=571
  _PEERINGGROUPRESOURCEGETRESPONSE._serialized_start=574
  _PEERINGGROUPRESOURCEGETRESPONSE._serialized_end=829
  _PEERINGGROUPRESOURCEDELETEREQUEST._serialized_start=831
  _PEERINGGROUPRESOURCEDELETEREQUEST._serialized_end=931
  _PEERINGGROUPRESOURCEDELETERESPONSE._serialized_start=934
  _PEERINGGROUPRESOURCEDELETERESPONSE._serialized_end=1125
  _PEERINGGROUPRESOURCELISTREQUEST._serialized_start=1127
  _PEERINGGROUPRESOURCELISTREQUEST._serialized_end=1227
  _PEERINGGROUPRESOURCELISTRESPONSE._serialized_start=1230
  _PEERINGGROUPRESOURCELISTRESPONSE._serialized_end=1464
  _PEERINGGROUPRESOURCE._serialized_start=1467
  _PEERINGGROUPRESOURCE._serialized_end=1598
  _PEERINGGROUPRESOURCES._serialized_start=1601
  _PEERINGGROUPRESOURCES._serialized_end=2263
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: role_resources.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14role_resources.proto\x12\x02v1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\roptions.proto\x1a\nspec.proto\"\x86\x01\n\x17RoleResourceListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xfb\x01\n\x18RoleResourceListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x34\n\x0erole_resources\x18\x02 \x03(\x0b\x32\x10.v1.RoleResourceB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:(\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider\"\xbc\x01\n\x0cRoleResource\x12\x1b\n\x07role_id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1f\n\x0bresource_id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12:\n\ngranted_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:2\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\xfa\xf8\xb3\x07\x06\xd2\xf3\xb3\x07\x01*\xfa\xf8\xb3\x07\x18\xd2\xf3\xb3\x07\x13!terraform-provider2\xbd\x01\n\rRoleResources\x12l\n\x04List\x12\x1b.v1.RoleResourceListRequest\x1a\x1c.v1.RoleResourceListResponse\")\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/role-resources\x1a>\xca\xf9\xb3\x07\x11\xc2\xf9\xb3\x07\x0cRoleResource\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\x18\xca\xf9\xb3\x07\x13!terraform-providerB\x91\x01\n\x19\x63om.strongdm.api.plumbingB\x15RoleResourcesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\xc2\x92\xb4\x07\x06\xa2\x8c\xb4\x07\x01*\xc2\x92\xb4\x07\x18\xa2\x8c\xb4\x07\x13!terraform-providerb\x06proto3')



_ROLERESOURCELISTREQUEST = DESCRIPTOR.message_types_by_name['RoleResourceListRequest']
_ROLERESOURCELISTRESPONSE = DESCRIPTOR.message_types_by_name['RoleResourceListResponse']
_ROLERESOURCE = DESCRIPTOR.message_types_by_name['RoleResource']
RoleResourceListRequest = _reflection.GeneratedProtocolMessageType('RoleResourceListRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLERESOURCELISTREQUEST,
  '__module__' : 'role_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleResourceListRequest)
  })
_sym_db.RegisterMessage(RoleResourceListRequest)

RoleResourceListResponse = _reflection.GeneratedProtocolMessageType('RoleResourceListResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLERESOURCELISTRESPONSE,
  '__module__' : 'role_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleResourceListResponse)
  })
_sym_db.RegisterMessage(RoleResourceListResponse)

RoleResource = _reflection.GeneratedProtocolMessageType('RoleResource', (_message.Message,), {
  'DESCRIPTOR' : _ROLERESOURCE,
  '__module__' : 'role_resources_pb2'
  # @@protoc_insertion_point(class_scope:v1.RoleResource)
  })
_sym_db.RegisterMessage(RoleResource)

_ROLERESOURCES = DESCRIPTOR.services_by_name['RoleResources']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\025RoleResourcesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1\302\222\264\007\006\242\214\264\007\001*\302\222\264\007\030\242\214\264\007\023!terraform-provider'
  _ROLERESOURCELISTREQUEST.fields_by_name['filter']._options = None
  _ROLERESOURCELISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLERESOURCELISTREQUEST._options = None
  _ROLERESOURCELISTREQUEST._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ROLERESOURCELISTRESPONSE.fields_by_name['role_resources']._options = None
  _ROLERESOURCELISTRESPONSE.fields_by_name['role_resources']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _ROLERESOURCELISTRESPONSE.fields_by_name['rate_limit']._options = None
  _ROLERESOURCELISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _ROLERESOURCELISTRESPONSE._options = None
  _ROLERESOURCELISTRESPONSE._serialized_options = b'\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ROLERESOURCE.fields_by_name['role_id']._options = None
  _ROLERESOURCE.fields_by_name['role_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLERESOURCE.fields_by_name['resource_id']._options = None
  _ROLERESOURCE.fields_by_name['resource_id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLERESOURCE.fields_by_name['granted_at']._options = None
  _ROLERESOURCE.fields_by_name['granted_at']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _ROLERESOURCE._options = None
  _ROLERESOURCE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001\372\370\263\007\006\322\363\263\007\001*\372\370\263\007\030\322\363\263\007\023!terraform-provider'
  _ROLERESOURCES._options = None
  _ROLERESOURCES._serialized_options = b'\312\371\263\007\021\302\371\263\007\014RoleResource\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\030\312\371\263\007\023!terraform-provider'
  _ROLERESOURCES.methods_by_name['List']._options = None
  _ROLERESOURCES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\027\252\363\263\007\022/v1/role-resources'
  _ROLERESOURCELISTREQUEST._serialized_start=89
  _ROLERESOURCELISTREQUEST._serialized_end=223
  _ROLERESOURCELISTRESPONSE._serialized_start=226
  _ROLERESOURCELISTRESPONSE._serialized_end=477
  _ROLERESOURCE._serialized_start=480
  _ROLERESOURCE._serialized_end=668
  _ROLERESOURCES._serialized_start=671
  _ROLERESOURCES._serialized_end=860
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: policies.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0epolicies.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"f\n\x13PolicyCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12&\n\x06policy\x18\x02 \x01(\x0b\x32\n.v1.PolicyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xcd\x01\n\x14PolicyCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12&\n\x06policy\x18\x02 \x01(\x0b\x32\n.v1.PolicyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"r\n\x13PolicyUpdateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.UpdateRequestMetadata\x12\n\n\x02id\x18\x02 \x01(\t\x12&\n\x06policy\x18\x03 \x01(\x0b\x32\n.v1.PolicyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xcd\x01\n\x14PolicyUpdateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.UpdateResponseMetadata\x12&\n\x06policy\x18\x02 \x01(\x0b\x32\n.v1.PolicyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"V\n\x13PolicyDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xa5\x01\n\x14PolicyDeleteResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadata\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"P\n\x10PolicyGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xd3\x01\n\x11PolicyGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12&\n\x06policy\x18\x02 \x01(\x0b\x32\n.v1.PolicyB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"V\n\x11PolicyListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xcb\x01\n\x12PolicyListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12(\n\x08policies\x18\x02 \x03(\x0b\x32\n.v1.PolicyB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xd8\x01\n\x06Policy\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1d\n\x04name\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12\x1f\n\x0b\x64\x65scription\x18\x03 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x1a\n\x06policy\x18\x04 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:Z\xfa\xf8\xb3\x07U\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07K\xa2\xf3\xb3\x07\x1ftf_examples/policy_resource.txt\xaa\xf3\xb3\x07\"tf_examples/policy_data_source.txt2\xba\x04\n\x08Policies\x12\x61\n\x06\x43reate\x12\x17.v1.PolicyCreateRequest\x1a\x18.v1.PolicyCreateResponse\"$\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x11\xaa\xf3\xb3\x07\x0c/v1/policies\x12h\n\x06\x44\x65lete\x12\x17.v1.PolicyDeleteRequest\x1a\x18.v1.PolicyDeleteResponse\"+\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x16\xaa\xf3\xb3\x07\x11/v1/policies/{id}\x12\x65\n\x06Update\x12\x17.v1.PolicyUpdateRequest\x1a\x18.v1.PolicyUpdateResponse\"(\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03put\x82\xf9\xb3\x07\x16\xaa\xf3\xb3\x07\x11/v1/policies/{id}\x12\\\n\x03Get\x12\x14.v1.PolicyGetRequest\x1a\x15.v1.PolicyGetResponse\"(\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x16\xaa\xf3\xb3\x07\x11/v1/policies/{id}\x12Z\n\x04List\x12\x15.v1.PolicyListRequest\x1a\x16.v1.PolicyListResponse\"#\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x11\xaa\xf3\xb3\x07\x0c/v1/policies\x1a@\xca\xf9\xb3\x07\x0b\xc2\xf9\xb3\x07\x06Policy\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03po-\xca\xf9\xb3\x07\x06\xca\xf9\xb3\x07\x01*\xca\xf9\xb3\x07\t\xca\xf9\xb3\x07\x04!cli\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42\x64\n\x19\x63om.strongdm.api.plumbingB\x10PoliciesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_POLICYCREATEREQUEST = DESCRIPTOR.message_types_by_name['PolicyCreateRequest']
_POLICYCREATERESPONSE = DESCRIPTOR.message_types_by_name['PolicyCreateResponse']
_POLICYUPDATEREQUEST = DESCRIPTOR.message_types_by_name['PolicyUpdateRequest']
_POLICYUPDATERESPONSE = DESCRIPTOR.message_types_by_name['PolicyUpdateResponse']
_POLICYDELETEREQUEST = DESCRIPTOR.message_types_by_name['PolicyDeleteRequest']
_POLICYDELETERESPONSE = DESCRIPTOR.message_types_by_name['PolicyDeleteResponse']
_POLICYGETREQUEST = DESCRIPTOR.message_types_by_name['PolicyGetRequest']
_POLICYGETRESPONSE = DESCRIPTOR.message_types_by_name['PolicyGetResponse']
_POLICYLISTREQUEST = DESCRIPTOR.message_types_by_name['PolicyListRequest']
_POLICYLISTRESPONSE = DESCRIPTOR.message_types_by_name['PolicyListResponse']
_POLICY = DESCRIPTOR.message_types_by_name['Policy']
PolicyCreateRequest = _reflection.GeneratedProtocolMessageType('PolicyCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _POLICYCREATEREQUEST,
  '__module__' : 'policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.PolicyCreateRequest)
  })
_sym_db.RegisterMessage(PolicyCreateRequest)

PolicyCreateResponse = _reflection.GeneratedProtocolMessageType('PolicyCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _POLICYCREATERESPONSE,
  '__module__' : 'policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.PolicyCreateResponse)
  })
_sym_db.RegisterMessage(PolicyCreateResponse)

PolicyUpdateRequest = _reflection.GeneratedProtocolMessageType('PolicyUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _POLICYUPDATEREQUEST,
  '__module__' : 'policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.PolicyUpdateRequest)
  })
_sym_db.RegisterMessage(PolicyUpdateRequest)

PolicyUpdateResponse = _reflection.GeneratedProtocolMessageType('PolicyUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _POLICYUPDATERESPONSE,
  '__module__' : 'policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.PolicyUpdateResponse)
  })
_sym_db.RegisterMessage(PolicyUpdateResponse)

PolicyDeleteRequest = _reflection.GeneratedProtocolMessageType('PolicyDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _POLICYDELETEREQUEST,
  '__module__' : 'policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.PolicyDeleteRequest)
  })
_sym_db.RegisterMessage(PolicyDeleteRequest)

PolicyDeleteResponse = _reflection.GeneratedProtocolMessageType('PolicyDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _POLICYDELETERESPONSE,
  '__module__' : 'policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.PolicyDeleteResponse)
  })
_sym_db.RegisterMessage(PolicyDeleteResponse)

PolicyGetRequest = _reflection.GeneratedProtocolMessageType('PolicyGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _POLICYGETREQUEST,
  '__module__' : 'policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.PolicyGetRequest)
  })
_sym_db.RegisterMessage(PolicyGetRequest)

PolicyGetResponse = _reflection.GeneratedProtocolMessageType('PolicyGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _POLICYGETRESPONSE,
  '__module__' : 'policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.PolicyGetResponse)
  })
_sym_db.RegisterMessage(PolicyGetResponse)

PolicyListRequest = _reflection.GeneratedProtocolMessageType('PolicyListRequest', (_message.Message,), {
  'DESCRIPTOR' : _POLICYLISTREQUEST,
  '__module__' : 'policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.PolicyListRequest)
  })
_sym_db.RegisterMessage(PolicyListRequest)

PolicyListResponse = _reflection.GeneratedProtocolMessageType('PolicyListResponse', (_message.Message,), {
  'DESCRIPTOR' : _POLICYLISTRESPONSE,
  '__module__' : 'policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.PolicyListResponse)
  })
_sym_db.RegisterMessage(PolicyListResponse)

Policy = _reflection.GeneratedProtocolMessageType('Policy', (_message.Message,), {
  'DESCRIPTOR' : _POLICY,
  '__module__' : 'policies_pb2'
  # @@protoc_insertion_point(class_scope:v1.Policy)
  })
_sym_db.RegisterMessage(Policy)

_POLICIES = DESCRIPTOR.services_by_name['Policies']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\020PoliciesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _POLICYCREATEREQUEST.fields_by_name['policy']._options = None
  _POLICYCREATEREQUEST.fields_by_name['policy']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POLICYCREATERESPONSE.fields_by_name['policy']._options = None
  _POLICYCREATERESPONSE.fields_by_name['policy']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POLICYCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _POLICYCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _POLICYCREATERESPONSE._options = None
  _POLICYCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _POLICYUPDATEREQUEST.fields_by_name['policy']._options = None
  _POLICYUPDATEREQUEST.fields_by_name['policy']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POLICYUPDATERESPONSE.fields_by_name['policy']._options = None
  _POLICYUPDATERESPONSE.fields_by_name['policy']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POLICYUPDATERESPONSE.fields_by_name['rate_limit']._options = None
  _POLICYUPDATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _POLICYUPDATERESPONSE._options = None
  _POLICYUPDATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _POLICYDELETEREQUEST.fields_by_name['id']._options = None
  _POLICYDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POLICYDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _POLICYDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _POLICYDELETERESPONSE._options = None
  _POLICYDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _POLICYGETREQUEST.fields_by_name['id']._options = None
  _POLICYGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POLICYGETRESPONSE.fields_by_name['meta']._options = None
  _POLICYGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POLICYGETRESPONSE.fields_by_name['policy']._options = None
  _POLICYGETRESPONSE.fields_by_name['policy']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POLICYGETRESPONSE.fields_by_name['rate_limit']._options = None
  _POLICYGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _POLICYGETRESPONSE._options = None
  _POLICYGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _POLICYLISTREQUEST.fields_by_name['filter']._options = None
  _POLICYLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POLICYLISTRESPONSE.fields_by_name['policies']._options = None
  _POLICYLISTRESPONSE.fields_by_name['policies']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _POLICYLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _POLICYLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _POLICYLISTRESPONSE._options = None
  _POLICYLISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _POLICY.fields_by_name['id']._options = None
  _POLICY.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POLICY.fields_by_name['name']._options = None
  _POLICY.fields_by_name['name']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _POLICY.fields_by_name['description']._options = None
  _POLICY.fields_by_name['description']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POLICY.fields_by_name['policy']._options = None
  _POLICY.fields_by_name['policy']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _POLICY._options = None
  _POLICY._serialized_options = b'\372\370\263\007U\250\363\263\007\001\302\363\263\007K\242\363\263\007\037tf_examples/policy_resource.txt\252\363\263\007\"tf_examples/policy_data_source.txt'
  _POLICIES._options = None
  _POLICIES._serialized_options = b'\312\371\263\007\013\302\371\263\007\006Policy\312\371\263\007\010\322\371\263\007\003po-\312\371\263\007\006\312\371\263\007\001*\312\371\263\007\t\312\371\263\007\004!cli\312\371\263\007\005\350\371\263\007\001'
  _POLICIES.methods_by_name['Create']._options = None
  _POLICIES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\021\252\363\263\007\014/v1/policies'
  _POLICIES.methods_by_name['Delete']._options = None
  _POLICIES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\026\252\363\263\007\021/v1/policies/{id}'
  _POLICIES.methods_by_name['Update']._options = None
  _POLICIES.methods_by_name['Update']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003put\202\371\263\007\026\252\363\263\007\021/v1/policies/{id}'
  _POLICIES.methods_by_name['Get']._options = None
  _POLICIES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\026\252\363\263\007\021/v1/policies/{id}'
  _POLICIES.methods_by_name['List']._options = None
  _POLICIES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\021\252\363\263\007\014/v1/policies'
  _POLICYCREATEREQUEST._serialized_start=49
  _POLICYCREATEREQUEST._serialized_end=151
  _POLICYCREATERESPONSE._serialized_start=154
  _POLICYCREATERESPONSE._serialized_end=359
  _POLICYUPDATEREQUEST._serialized_start=361
  _POLICYUPDATEREQUEST._serialized_end=475
  _POLICYUPDATERESPONSE._serialized_start=478
  _POLICYUPDATERESPONSE._serialized_end=683
  _POLICYDELETEREQUEST._serialized_start=685
  _POLICYDELETEREQUEST._serialized_end=771
  _POLICYDELETERESPONSE._serialized_start=774
  _POLICYDELETERESPONSE._serialized_end=939
  _POLICYGETREQUEST._serialized_start=941
  _POLICYGETREQUEST._serialized_end=1021
  _POLICYGETRESPONSE._serialized_start=1024
  _POLICYGETRESPONSE._serialized_end=1235
  _POLICYLISTREQUEST._serialized_start=1237
  _POLICYLISTREQUEST._serialized_end=1323
  _POLICYLISTRESPONSE._serialized_start=1326
  _POLICYLISTRESPONSE._serialized_end=1529
  _POLICY._serialized_start=1532
  _POLICY._serialized_end=1748
  _POLICIES._serialized_start=1751
  _POLICIES._serialized_end=2321
# @@protoc_insertion_point(module_scope)



# Copyright 2020 StrongDM Inc
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# 
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: workflow_roles.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import options_pb2 as options__pb2
from . import spec_pb2 as spec__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14workflow_roles.proto\x12\x02v1\x1a\roptions.proto\x1a\nspec.proto\"\x86\x01\n\x1aWorkflowRolesCreateRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.CreateRequestMetadata\x12\x33\n\rworkflow_role\x18\x02 \x01(\x0b\x32\x10.v1.WorkflowRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xe1\x01\n\x1bWorkflowRolesCreateResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.CreateResponseMetadata\x12\x33\n\rworkflow_role\x18\x02 \x01(\x0b\x32\x10.v1.WorkflowRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"V\n\x16WorkflowRoleGetRequest\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.v1.GetRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\"\xe6\x01\n\x17WorkflowRoleGetResponse\x12\x31\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.GetResponseMetadataB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12\x33\n\rworkflow_role\x18\x02 \x01(\x0b\x32\x10.v1.WorkflowRoleB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"i\n\x1aWorkflowRolesDeleteRequest\x12\'\n\x04meta\x18\x01 \x01(\x0b\x32\x19.v1.DeleteRequestMetadata\x12\x16\n\x02id\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xac\x01\n\x1bWorkflowRolesDeleteResponse\x12(\n\x04meta\x18\x01 \x01(\x0b\x32\x1a.v1.DeleteResponseMetadata\x12W\n\nrate_limit\x18\x02 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"i\n\x18WorkflowRolesListRequest\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.v1.ListRequestMetadata\x12\x1a\n\x06\x66ilter\x18\x02 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xdd\x01\n\x19WorkflowRolesListResponse\x12&\n\x04meta\x18\x01 \x01(\x0b\x32\x18.v1.ListResponseMetadata\x12\x33\n\rworkflow_role\x18\x02 \x03(\x0b\x32\x10.v1.WorkflowRoleB\n\xf2\xf8\xb3\x07\x05\xb8\xf3\xb3\x07\x01\x12W\n\nrate_limit\x18\x03 \x01(\x0b\x32\x15.v1.RateLimitMetadataB,\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\xf2\xf8\xb3\x07\x06\xb2\xf4\xb3\x07\x01*\xf2\xf8\xb3\x07\x12\xb2\xf4\xb3\x07\r!json_gateway:\n\xfa\xf8\xb3\x07\x05\xa8\xf3\xb3\x07\x01\"\xde\x01\n\x0cWorkflowRole\x12\x16\n\x02id\x18\x01 \x01(\tB\n\xf2\xf8\xb3\x07\x05\xb0\xf3\xb3\x07\x01\x12$\n\x0bworkflow_id\x18\x02 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01\x12 \n\x07role_id\x18\x03 \x01(\tB\x0f\xf2\xf8\xb3\x07\n\xb0\xf3\xb3\x07\x01\xc0\xf3\xb3\x07\x01:n\xfa\xf8\xb3\x07i\xa8\xf3\xb3\x07\x01\xc2\xf3\xb3\x07Y\xa2\xf3\xb3\x07&tf_examples/workflow_role_resource.txt\xaa\xf3\xb3\x07)tf_examples/workflow_role_data_source.txt\xd2\xf3\xb3\x07\x01*2\x8d\x04\n\rWorkflowRoles\x12u\n\x06\x43reate\x12\x1e.v1.WorkflowRolesCreateRequest\x1a\x1f.v1.WorkflowRolesCreateResponse\"*\x82\xf9\xb3\x07\t\xa2\xf3\xb3\x07\x04post\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/workflow-roles\x12m\n\x03Get\x12\x1a.v1.WorkflowRoleGetRequest\x1a\x1b.v1.WorkflowRoleGetResponse\"-\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x1b\xaa\xf3\xb3\x07\x16/v1/workflow-role/{id}\x12w\n\x06\x44\x65lete\x12\x1e.v1.WorkflowRolesDeleteRequest\x1a\x1f.v1.WorkflowRolesDeleteResponse\",\x82\xf9\xb3\x07\x0b\xa2\xf3\xb3\x07\x06\x64\x65lete\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/workflow-roles\x12n\n\x04List\x12\x1c.v1.WorkflowRolesListRequest\x1a\x1d.v1.WorkflowRolesListResponse\")\x82\xf9\xb3\x07\x08\xa2\xf3\xb3\x07\x03get\x82\xf9\xb3\x07\x17\xaa\xf3\xb3\x07\x12/v1/workflow-roles\x1a-\xca\xf9\xb3\x07\x11\xc2\xf9\xb3\x07\x0cWorkflowRole\xca\xf9\xb3\x07\x08\xd2\xf9\xb3\x07\x03wr-\xca\xf9\xb3\x07\x05\xe8\xf9\xb3\x07\x01\x42i\n\x19\x63om.strongdm.api.plumbingB\x15WorkflowRolesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1b\x06proto3')



_WORKFLOWROLESCREATEREQUEST = DESCRIPTOR.message_types_by_name['WorkflowRolesCreateRequest']
_WORKFLOWROLESCREATERESPONSE = DESCRIPTOR.message_types_by_name['WorkflowRolesCreateResponse']
_WORKFLOWROLEGETREQUEST = DESCRIPTOR.message_types_by_name['WorkflowRoleGetRequest']
_WORKFLOWROLEGETRESPONSE = DESCRIPTOR.message_types_by_name['WorkflowRoleGetResponse']
_WORKFLOWROLESDELETEREQUEST = DESCRIPTOR.message_types_by_name['WorkflowRolesDeleteRequest']
_WORKFLOWROLESDELETERESPONSE = DESCRIPTOR.message_types_by_name['WorkflowRolesDeleteResponse']
_WORKFLOWROLESLISTREQUEST = DESCRIPTOR.message_types_by_name['WorkflowRolesListRequest']
_WORKFLOWROLESLISTRESPONSE = DESCRIPTOR.message_types_by_name['WorkflowRolesListResponse']
_WORKFLOWROLE = DESCRIPTOR.message_types_by_name['WorkflowRole']
WorkflowRolesCreateRequest = _reflection.GeneratedProtocolMessageType('WorkflowRolesCreateRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLESCREATEREQUEST,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRolesCreateRequest)
  })
_sym_db.RegisterMessage(WorkflowRolesCreateRequest)

WorkflowRolesCreateResponse = _reflection.GeneratedProtocolMessageType('WorkflowRolesCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLESCREATERESPONSE,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRolesCreateResponse)
  })
_sym_db.RegisterMessage(WorkflowRolesCreateResponse)

WorkflowRoleGetRequest = _reflection.GeneratedProtocolMessageType('WorkflowRoleGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLEGETREQUEST,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRoleGetRequest)
  })
_sym_db.RegisterMessage(WorkflowRoleGetRequest)

WorkflowRoleGetResponse = _reflection.GeneratedProtocolMessageType('WorkflowRoleGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLEGETRESPONSE,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRoleGetResponse)
  })
_sym_db.RegisterMessage(WorkflowRoleGetResponse)

WorkflowRolesDeleteRequest = _reflection.GeneratedProtocolMessageType('WorkflowRolesDeleteRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLESDELETEREQUEST,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRolesDeleteRequest)
  })
_sym_db.RegisterMessage(WorkflowRolesDeleteRequest)

WorkflowRolesDeleteResponse = _reflection.GeneratedProtocolMessageType('WorkflowRolesDeleteResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLESDELETERESPONSE,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRolesDeleteResponse)
  })
_sym_db.RegisterMessage(WorkflowRolesDeleteResponse)

WorkflowRolesListRequest = _reflection.GeneratedProtocolMessageType('WorkflowRolesListRequest', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLESLISTREQUEST,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRolesListRequest)
  })
_sym_db.RegisterMessage(WorkflowRolesListRequest)

WorkflowRolesListResponse = _reflection.GeneratedProtocolMessageType('WorkflowRolesListResponse', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLESLISTRESPONSE,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRolesListResponse)
  })
_sym_db.RegisterMessage(WorkflowRolesListResponse)

WorkflowRole = _reflection.GeneratedProtocolMessageType('WorkflowRole', (_message.Message,), {
  'DESCRIPTOR' : _WORKFLOWROLE,
  '__module__' : 'workflow_roles_pb2'
  # @@protoc_insertion_point(class_scope:v1.WorkflowRole)
  })
_sym_db.RegisterMessage(WorkflowRole)

_WORKFLOWROLES = DESCRIPTOR.services_by_name['WorkflowRoles']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.strongdm.api.plumbingB\025WorkflowRolesPlumbingZ5github.com/strongdm/strongdm-sdk-go/v3/internal/v1;v1'
  _WORKFLOWROLESCREATEREQUEST.fields_by_name['workflow_role']._options = None
  _WORKFLOWROLESCREATEREQUEST.fields_by_name['workflow_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLESCREATEREQUEST._options = None
  _WORKFLOWROLESCREATEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLESCREATERESPONSE.fields_by_name['workflow_role']._options = None
  _WORKFLOWROLESCREATERESPONSE.fields_by_name['workflow_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLESCREATERESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWROLESCREATERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWROLESCREATERESPONSE._options = None
  _WORKFLOWROLESCREATERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLEGETREQUEST.fields_by_name['id']._options = None
  _WORKFLOWROLEGETREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLEGETRESPONSE.fields_by_name['meta']._options = None
  _WORKFLOWROLEGETRESPONSE.fields_by_name['meta']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLEGETRESPONSE.fields_by_name['workflow_role']._options = None
  _WORKFLOWROLEGETRESPONSE.fields_by_name['workflow_role']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLEGETRESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWROLEGETRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWROLEGETRESPONSE._options = None
  _WORKFLOWROLEGETRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLESDELETEREQUEST.fields_by_name['id']._options = None
  _WORKFLOWROLESDELETEREQUEST.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLESDELETEREQUEST._options = None
  _WORKFLOWROLESDELETEREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLESDELETERESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWROLESDELETERESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWROLESDELETERESPONSE._options = None
  _WORKFLOWROLESDELETERESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLESLISTREQUEST.fields_by_name['filter']._options = None
  _WORKFLOWROLESLISTREQUEST.fields_by_name['filter']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLESLISTREQUEST._options = None
  _WORKFLOWROLESLISTREQUEST._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLESLISTRESPONSE.fields_by_name['workflow_role']._options = None
  _WORKFLOWROLESLISTRESPONSE.fields_by_name['workflow_role']._serialized_options = b'\362\370\263\007\005\270\363\263\007\001'
  _WORKFLOWROLESLISTRESPONSE.fields_by_name['rate_limit']._options = None
  _WORKFLOWROLESLISTRESPONSE.fields_by_name['rate_limit']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001\362\370\263\007\006\262\364\263\007\001*\362\370\263\007\022\262\364\263\007\r!json_gateway'
  _WORKFLOWROLESLISTRESPONSE._options = None
  _WORKFLOWROLESLISTRESPONSE._serialized_options = b'\372\370\263\007\005\250\363\263\007\001'
  _WORKFLOWROLE.fields_by_name['id']._options = None
  _WORKFLOWROLE.fields_by_name['id']._serialized_options = b'\362\370\263\007\005\260\363\263\007\001'
  _WORKFLOWROLE.fields_by_name['workflow_id']._options = None
  _WORKFLOWROLE.fields_by_name['workflow_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _WORKFLOWROLE.fields_by_name['role_id']._options = None
  _WORKFLOWROLE.fields_by_name['role_id']._serialized_options = b'\362\370\263\007\n\260\363\263\007\001\300\363\263\007\001'
  _WORKFLOWROLE._options = None
  _WORKFLOWROLE._serialized_options = b'\372\370\263\007i\250\363\263\007\001\302\363\263\007Y\242\363\263\007&tf_examples/workflow_role_resource.txt\252\363\263\007)tf_examples/workflow_role_data_source.txt\322\363\263\007\001*'
  _WORKFLOWROLES._options = None
  _WORKFLOWROLES._serialized_options = b'\312\371\263\007\021\302\371\263\007\014WorkflowRole\312\371\263\007\010\322\371\263\007\003wr-\312\371\263\007\005\350\371\263\007\001'
  _WORKFLOWROLES.methods_by_name['Create']._options = None
  _WORKFLOWROLES.methods_by_name['Create']._serialized_options = b'\202\371\263\007\t\242\363\263\007\004post\202\371\263\007\027\252\363\263\007\022/v1/workflow-roles'
  _WORKFLOWROLES.methods_by_name['Get']._options = None
  _WORKFLOWROLES.methods_by_name['Get']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\033\252\363\263\007\026/v1/workflow-role/{id}'
  _WORKFLOWROLES.methods_by_name['Delete']._options = None
  _WORKFLOWROLES.methods_by_name['Delete']._serialized_options = b'\202\371\263\007\013\242\363\263\007\006delete\202\371\263\007\027\252\363\263\007\022/v1/workflow-roles'
  _WORKFLOWROLES.methods_by_name['List']._options = None
  _WORKFLOWROLES.methods_by_name['List']._serialized_options = b'\202\371\263\007\010\242\363\263\007\003get\202\371\263\007\027\252\363\263\007\022/v1/workflow-roles'
  _WORKFLOWROLESCREATEREQUEST._serialized_start=56
  _WORKFLOWROLESCREATEREQUEST._serialized_end=190
  _WORKFLOWROLESCREATERESPONSE._serialized_start=193
  _WORKFLOWROLESCREATERESPONSE._serialized_end=418
  _WORKFLOWROLEGETREQUEST._serialized_start=420
  _WORKFLOWROLEGETREQUEST._serialized_end=506
  _WORKFLOWROLEGETRESPONSE._serialized_start=509
  _WORKFLOWROLEGETRESPONSE._serialized_end=739
  _WORKFLOWROLESDELETEREQUEST._serialized_start=741
  _WORKFLOWROLESDELETEREQUEST._serialized_end=846
  _WORKFLOWROLESDELETERESPONSE._serialized_start=849
  _WORKFLOWROLESDELETERESPONSE._serialized_end=1021
  _WORKFLOWROLESLISTREQUEST._serialized_start=1023
  _WORKFLOWROLESLISTREQUEST._serialized_end=1128
  _WORKFLOWROLESLISTRESPONSE._serialized_start=1131
  _WORKFLOWROLESLISTRESPONSE._serialized_end=1352
  _WORKFLOWROLE._serialized_start=1355
  _WORKFLOWROLE._serialized_end=1577
  _WORKFLOWROLES._serialized_start=1580
  _WORKFLOWROLES._serialized_end=2105
# @@protoc_insertion_point(module_scope)
